@@ -16,9 +16,12 @@
 
 package net.rubygrapefruit.platform.internal.jni;
 
+import net.rubygrapefruit.platform.internal.DirList;
 import net.rubygrapefruit.platform.internal.FunctionResult;
 import net.rubygrapefruit.platform.internal.WindowsFileStat;
 
 public class WindowsFileFunctions {
     public static native void stat(String file, WindowsFileStat stat, FunctionResult result);
+
+    public static native void readdir(String path, DirList dirList, FunctionResult result);
 }
